@@ -33,6 +33,9 @@ from pychess.widgets.TaskerManager import internet_game_tasker
 from pychess.widgets.RecentChooser import recent_menu, recent_manager
 from pychess.Players.engineNest import discoverer
 from pychess.Savers import chesspastebin
+from pychess.Savers.remotegame import get_internet_game_as_pgn
+from pychess.System.protoopen import splitUri
+from pychess.widgets import mainwindow
 from pychess.ic import ICLogon
 from pychess.perspectives import perspective_manager
 from pychess.perspectives.welcome import Welcome
@@ -58,7 +61,7 @@ DRAG_RESTRICT = Gtk.TargetFlags.OTHER_APP
 DND_LIST = [Gtk.TargetEntry.new("text/uri-list", DRAG_RESTRICT, TARGET_TYPE_URI_LIST)]
 
 
-class GladeHandlers(object):
+class GladeHandlers:
     def __init__(self, app):
         self.app = app
 
@@ -161,19 +164,109 @@ class GladeHandlers(object):
 
     def on_drag_received(self, widget, context, x, y, selection, target_type, timestamp):
         if target_type == TARGET_TYPE_URI_LIST:
+            NOTPROC, PARTIAL, FULL = range(3)
+            status = NOTPROC
             uris = selection.get_uris()
             for uri in uris:
-                if uri.lower().endswith(".fen"):
-                    newGameDialog.loadFileAndRun(uri)
+                fn, fext = os.path.splitext(uri.lower())
+                b = False
+
+                # Chess position
+                if fext == '.fen':
+                    b = newGameDialog.loadFileAndRun(uri)
+
+                # Shortcut
+                elif fext in ['.url', '.desktop']:
+                    # Preconf
+                    if fext == '.url':
+                        sectname = 'InternetShortcut'
+                        typeok = True
+                    elif fext == '.desktop':
+                        sectname = 'Desktop Entry'
+                        typeok = False
+                    else:
+                        assert(False)
+
+                    # Read the shortcut
+                    filename = splitUri(uri)[1]
+                    with open(filename, 'r') as file:
+                        content = file.read()
+                    lines = content.replace("\r", '').split("\n")
+
+                    # Extract the link
+                    section = False
+                    link = ''
+                    for item in lines:
+                        # Header
+                        if item.startswith('['):
+                            if section:
+                                break
+                            section = item.startswith('[%s]' % sectname)
+                        if not section:
+                            continue
+
+                        # Item
+                        if item.startswith('URL='):
+                            link = item[4:]
+                        if item.startswith('Type=Link') and fext == '.desktop':
+                            typeok = True
+
+                    # Load the link
+                    if typeok and link != '':
+                        pgn = get_internet_game_as_pgn(link)
+                        b = newGameDialog.loadPgnAndRun(pgn)
+
+                # Database
                 else:
                     perspective = perspective_manager.get_perspective("database")
                     perspective.open_chessfile(uri)
+                    b = True
+
+                # Update the global status
+                if b:
+                    if status == NOTPROC:
+                        status = FULL
+                else:
+                    if status != NOTPROC:
+                        status = PARTIAL
+
+            # Feedback about the load
+            msg = ''
+            if status == NOTPROC:
+                msg = _('All the links failed to fetch a relevant chess content.')
+                msgtype = Gtk.MessageType.ERROR
+            elif status == PARTIAL:
+                msg = _('Some links were invalid.')
+                msgtype = Gtk.MessageType.WARNING
+            if msg != '':
+                dlg = Gtk.MessageDialog(mainwindow(), type=msgtype, buttons=Gtk.ButtonsType.OK, message_format=msg)
+                dlg.run()
+                dlg.destroy()
 
     # Game Menu
 
     def on_new_game1_activate(self, widget):
         newGameDialog.NewGameMode.run()
 
+    def on_set_up_position_activate(self, widget):
+        rotate_menu = gamewidget.getWidgets()["rotate_board1"]
+        rotate_menu.set_sensitive(True)
+        persp = perspective_manager.get_perspective("games")
+        gmwidg = persp.cur_gmwidg()
+        if gmwidg is not None:
+            ply = gmwidg.board.view.shown
+            variation = gmwidg.board.view.shown_variation_idx
+            board = gmwidg.gamemodel.getBoardAtPly(ply, variation)
+            fen = board.asFen()
+            variant = board.variant
+        else:
+            fen = None
+            variant = NORMALCHESS
+        newGameDialog.SetupPositionExtension.run(fen, variant)
+
+    def on_enter_game_notation_activate(self, widget):
+        newGameDialog.EnterNotationExtension.run()
+
     def on_play_internet_chess_activate(self, widget):
         ICLogon.run()
 
@@ -196,24 +289,33 @@ class GladeHandlers(object):
                     perspective = perspective_manager.get_perspective("database")
                     perspective.open_chessfile(filename)
 
-    def on_set_up_position_activate(self, widget):
-        rotate_menu = gamewidget.getWidgets()["rotate_board1"]
-        rotate_menu.set_sensitive(True)
-        persp = perspective_manager.get_perspective("games")
-        gmwidg = persp.cur_gmwidg()
-        if gmwidg is not None:
-            ply = gmwidg.board.view.shown
-            variation = gmwidg.board.view.shown_variation_idx
-            board = gmwidg.gamemodel.getBoardAtPly(ply, variation)
-            fen = board.asFen()
-            variant = board.variant
-        else:
-            fen = None
-            variant = NORMALCHESS
-        newGameDialog.SetupPositionExtension.run(fen, variant)
+    def on_remote_game_activate(self, widget):
+        # Ask the user for an URL
+        widgets = gamewidget.getWidgets()
+        url_dialog = widgets["url_path_dialog"]
+        widgets["url_edit"].set_text('')
+        widgets["url_edit"].grab_focus()
+        answer = url_dialog.run()
+        url_dialog.hide()
+        if answer != Gtk.ResponseType.OK.real:
+            return
 
-    def on_enter_game_notation_activate(self, widget):
-        newGameDialog.EnterNotationExtension.run()
+        # Download the game
+        url = widgets["url_edit"].get_text().strip()
+        if len(url) == 0:
+            return
+        remdata = get_internet_game_as_pgn(url)
+        if remdata is None:
+            dlg = Gtk.MessageDialog(mainwindow(),
+                                    type=Gtk.MessageType.ERROR,
+                                    buttons=Gtk.ButtonsType.OK,
+                                    message_format=_("The provided link does not lead to a meaningful chess content."))
+            dlg.run()
+            dlg.destroy()
+            return
+
+        # Load the game
+        newGameDialog.loadPgnAndRun(remdata)
 
     def on_save_game1_activate(self, widget):
         perspective = perspective_manager.get_perspective("games")
@@ -227,11 +329,6 @@ class GladeHandlers(object):
         position = gmwidg.board.view.shown
         perspective.saveGameAs(gmwidg.gamemodel, position)
 
-    def on_share_game_activate(self, widget):
-        perspective = perspective_manager.get_perspective("games")
-        gmwidg = perspective.cur_gmwidg()
-        chesspastebin.paste(gmwidg.gamemodel)
-
     def on_export_position_activate(self, widget):
         perspective = perspective_manager.get_perspective("games")
         gmwidg = perspective.cur_gmwidg()
@@ -239,13 +336,18 @@ class GladeHandlers(object):
         perspective = perspective_manager.get_perspective("games")
         perspective.saveGameAs(gmwidg.gamemodel, position, export=True)
 
-    def on_analyze_game_activate(self, widget):
-        analyze_game_dialog = AnalyzeGameDialog()
-        analyze_game_dialog.run()
+    def on_share_game_activate(self, widget):
+        perspective = perspective_manager.get_perspective("games")
+        gmwidg = perspective.cur_gmwidg()
+        chesspastebin.paste(gmwidg.gamemodel)
 
     def on_properties1_activate(self, widget):
         gameinfoDialog.run(gamewidget.getWidgets())
 
+    def on_analyze_game_activate(self, widget):
+        analyze_game_dialog = AnalyzeGameDialog()
+        analyze_game_dialog.run()
+
     def on_player_rating1_activate(self, widget):
         playerinfoDialog.run(gamewidget.getWidgets())
 
@@ -526,8 +628,8 @@ class PyChess(Gtk.Application):
         style_ctxt = gamewidget.getWidgets()["main_window"].get_style_context()
         LIGHT = hexcol(style_ctxt.lookup_color("p_light_color")[1])
         DARK = hexcol(style_ctxt.lookup_color("p_dark_color")[1])
-        conf.set("lightcolour", LIGHT)
-        conf.set("darkcolour", DARK)
+        conf.DEFAULTS["General"]["lightcolour"] = LIGHT
+        conf.DEFAULTS["General"]["darkcolour"] = DARK
 
         self.splash.destroy()
 
@@ -612,18 +714,15 @@ class PyChess(Gtk.Application):
         # About dialog
         self.aboutdialog = widgets["aboutdialog1"]
         self.aboutdialog.set_program_name(NAME)
-        self.aboutdialog.set_copyright("Copyright © 2006-2018")
+        self.aboutdialog.set_copyright("Copyright © 2006-2019")
         self.aboutdialog.set_version(VERSION_NAME + " " + VERSION)
         if os.path.isdir(prefix.addDataPrefix(".git")):
             try:
-                label = subprocess.check_output(["git", "describe"])
+                self.git_rev = subprocess.check_output(["git", "describe", "--tags"]).decode().strip()
+                self.aboutdialog.set_version('%s Git %s' % (VERSION_NAME, self.git_rev))
             except subprocess.CalledProcessError:
-                label = ""
-            if label:
-                comments = self.aboutdialog.get_comments()
-                self.git_rev = label
-                self.aboutdialog.set_comments("git %s\n%s" %
-                                              (self.git_rev, comments))
+                pass
+        self.aboutdialog.set_comments(self.aboutdialog.get_comments())
 
         with open(prefix.addDataPrefix("ARTISTS"), encoding="utf-8") as f:
             self.aboutdialog.set_artists(f.read().splitlines())
