@@ -4,6 +4,7 @@ import asyncio
 
 from gi.repository import GObject
 
+from pychess.compat import create_task
 from pychess.Utils.const import LOCAL, RUNNING
 from pychess.Variants.setupposition import SetupBoard
 
@@ -105,4 +106,4 @@ class SetupModel(GObject.GObject):
                     # print("CLOSE")
                     break
 
-        asyncio.async(coro())
+        create_task(coro())
