@@ -31,4 +31,4 @@ def perft(board, depth, root):
         nodes = do_perft(board, i + 1, root)
         ttime = time() - start_time
         print("%2d %10d %5.2f %12.2fnps" %
-              (i + 1, nodes, ttime, nodes / ttime))
+              (i + 1, nodes, ttime, nodes / ttime if ttime > 0 else nodes))
