@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
 
-import asyncio
 import os
 from io import StringIO
 
@@ -25,7 +24,7 @@ from pychess.Utils.TimeModel import TimeModel
 from pychess.Players.ICPlayer import ICPlayer
 from pychess.Players.Human import Human
 from pychess.Savers import pgn, fen
-from pychess.perspectives import Perspective, perspective_manager
+from pychess.perspectives import Perspective, perspective_manager, panel_name
 
 
 class PlayerNotificationMessage(InfoBarMessage):
@@ -110,7 +109,6 @@ class FICS(GObject.GObject, Perspective):
     def init_layout(self):
         perspective_widget = Gtk.Box(orientation=Gtk.Orientation.VERTICAL)
         perspective_manager.set_perspective_widget("fics", perspective_widget)
-        perspective_manager.set_perspective_menuitems("fics", self.menuitems)
 
         self.infobar = InfoBarNotebook("fics_lounge_infobar")
         self.infobar.hide()
@@ -126,16 +124,18 @@ class FICS(GObject.GObject, Perspective):
         self.notebooks = {"ficshome": new_notebook()}
         self.main_notebook = self.notebooks["ficshome"]
         for panel in self.sidePanels:
-            self.notebooks[panel.__name__] = new_notebook(panel.__name__)
+            self.notebooks[panel_name(panel.__name__)] = new_notebook(panel_name(panel.__name__))
 
         self.docks["ficshome"] = (Gtk.Label(label="ficshome"), self.notebooks["ficshome"], None)
         for panel in self.sidePanels:
-            self.docks[panel.__name__][1] = self.notebooks[panel.__name__]
+            self.docks[panel_name(panel.__name__)][1] = self.notebooks[panel_name(panel.__name__)]
 
         self.load_from_xml()
 
         # Default layout of side panels
+        first_time_layout = False
         if not os.path.isfile(self.dockLocation):
+            first_time_layout = True
             leaf = self.dock.dock(self.docks["ficshome"][1], CENTER, self.docks["ficshome"][0], "ficshome")
             leaf.setDockable(False)
 
@@ -160,6 +160,8 @@ class FICS(GObject.GObject, Perspective):
         self.dock.show_all()
         perspective_widget.show_all()
 
+        perspective_manager.set_perspective_menuitems("fics", self.menuitems, default=first_time_layout)
+
         log.debug("FICS.__init__: finished")
 
     def open_lounge(self, connection, helperconn, host):
@@ -250,8 +252,8 @@ class FICS(GObject.GObject, Perspective):
 
         for panel, instance in zip(self.sidePanels, self.panels):
             if not self.first_run:
-                self.notebooks[panel.__name__].remove_page(-1)
-            self.notebooks[panel.__name__].append_page(instance)
+                self.notebooks[panel_name(panel.__name__)].remove_page(-1)
+            self.notebooks[panel_name(panel.__name__)].append_page(instance)
             instance.show()
 
         tool_buttons = [self.logoff_button, ]
